@@ -4,6 +4,8 @@ from functools import cache
 from typing import Optional, Any
 from dataclasses import dataclass, fields, _MISSING_TYPE
 
+from starlette.requests import Request
+
 from .base import ApiMember
 from .tools import get_method_signature_data, format_field
 
@@ -52,7 +54,7 @@ class Event(ApiMember):
 		self.context = context or {}
 		self.outcomes = []
 
-	async def do(self, *args, **kwarg) -> Any:
+	async def do(self, request: Request, *args, **kwarg) -> Any:
 		pass
 
 	@classmethod
